Create structural functions for a causal model
Source:R/structural_functions.R
make_function_list.RdConverts a named causal model into a named list of R functions.
Each variable in the causal model is converted using
create_structural_function().